Module proto

Module proto 

Modules

column_encoding
Nested message and enum types in ColumnEncoding.
stream
Nested message and enum types in Stream.
type
Nested message and enum types in Type.

Structs

BinaryStatistics
BloomFilter
BloomFilterIndex
BucketStatistics
CollectionStatistics
Statistics for list and map
ColumnEncoding
ColumnStatistics
ColumnarStripeStatistics
In ORC v2 (and for encrypted columns in v1), each column has their column statistics written separately.
DataMask
How was the data masked? This isn’t necessary for reading the file, but is documentation about how the file was written.
DateStatistics
DecimalStatistics
DoubleStatistics
Encryption
EncryptionKey
Information about the encryption keys.
EncryptionVariant
The description of an encryption variant. Each variant is a single subtype that is encrypted with a single key.
FileStatistics
FileTail
The contents of the file tail that must be serialized. This gets serialized as part of OrcSplit, also used by footer cache.
Footer
IntegerStatistics
Metadata
This message type is only used in ORC v0 and v1.
PostScript
Serialized length must be less that 255 bytes
RowIndex
RowIndexEntry
Stream
StringPair
StringStatistics
StripeEncryptionVariant
StripeFooter
StripeInformation
StripeStatistics
StripeStatistics (1 per a stripe), which each contain the ColumnStatistics for each column. This message type is only used in ORC v0 and v1.
TimestampStatistics
Type
UserMetadataItem

Enums

CalendarKind
CompressionKind
EncryptionAlgorithm
KeyProviderKind
Which KeyProvider encrypted the local keys.