#[repr(i32)]pub enum CalendarKind {
UnknownCalendar = 0,
JulianGregorian = 1,
ProlepticGregorian = 2,
}Variants
UnknownCalendar = 0
JulianGregorian = 1
A hybrid Julian/Gregorian calendar with a cutover point in October 1582.
ProlepticGregorian = 2
A calendar that extends the Gregorian calendar back forever.
Implementations
Sourceimpl CalendarKind
impl CalendarKind
Sourceimpl CalendarKind
impl CalendarKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.