pub struct EncryptionVariant {
pub root: Option<u32>,
pub key: Option<u32>,
pub encrypted_key: Option<Vec<u8>>,
pub stripe_statistics: Vec<Stream>,
pub file_statistics: Option<Vec<u8>>,
}Expand description
The description of an encryption variant. Each variant is a single subtype that is encrypted with a single key.
Fields
root: Option<u32>the column id of the root
key: Option<u32>The master key that was used to encrypt the local key, referenced as an index into the Encryption.key list.
encrypted_key: Option<Vec<u8>>the encrypted key for the file footer
stripe_statistics: Vec<Stream>the stripe statistics for this variant
file_statistics: Option<Vec<u8>>encrypted file statistics as a FileStatistics
Implementations
Sourceimpl EncryptionVariant
impl EncryptionVariant
Sourcepub fn encrypted_key(&self) -> &[u8] ⓘ
pub fn encrypted_key(&self) -> &[u8] ⓘ
Returns the value of encrypted_key, or the default value if encrypted_key is unset.
Sourcepub fn file_statistics(&self) -> &[u8] ⓘ
pub fn file_statistics(&self) -> &[u8] ⓘ
Returns the value of file_statistics, or the default value if file_statistics is unset.