Footer

Struct Footer 

pub struct Footer {
    pub header_length: Option<u64>,
    pub content_length: Option<u64>,
    pub stripes: Vec<StripeInformation>,
    pub types: Vec<Type>,
    pub metadata: Vec<UserMetadataItem>,
    pub number_of_rows: Option<u64>,
    pub statistics: Vec<ColumnStatistics>,
    pub row_index_stride: Option<u32>,
    pub writer: Option<u32>,
    pub encryption: Option<Encryption>,
    pub calendar: Option<i32>,
    pub software_version: Option<String>,
}

Fields

header_length: Option<u64>content_length: Option<u64>stripes: Vec<StripeInformation>types: Vec<Type>metadata: Vec<UserMetadataItem>number_of_rows: Option<u64>statistics: Vec<ColumnStatistics>row_index_stride: Option<u32>writer: Option<u32>

Each implementation that writes ORC files should register for a code 0 = ORC Java 1 = ORC C++ 2 = Presto 3 = Scritchley Go from https://github.com/scritchley/orc 4 = Trino

encryption: Option<Encryption>

information about the encryption in this file

calendar: Option<i32>software_version: Option<String>

informative description about the version of the software that wrote the file. It is assumed to be within a given writer, so for example ORC 1.7.2 = “1.7.2”. It may include suffixes, such as “-SNAPSHOT”.

Implementations

pub fn header_length(&self) -> u64

Returns the value of header_length, or the default value if header_length is unset.

pub fn content_length(&self) -> u64

Returns the value of content_length, or the default value if content_length is unset.

pub fn number_of_rows(&self) -> u64

Returns the value of number_of_rows, or the default value if number_of_rows is unset.

pub fn row_index_stride(&self) -> u32

Returns the value of row_index_stride, or the default value if row_index_stride is unset.

pub fn writer(&self) -> u32

Returns the value of writer, or the default value if writer is unset.

pub fn calendar(&self) -> CalendarKind

Returns the enum value of calendar, or the default if the field is unset or set to an invalid enum value.

pub fn set_calendar(&mut self, value: CalendarKind)

Sets calendar to the provided enum value.

pub fn software_version(&self) -> &str

Returns the value of software_version, or the default value if software_version is unset.