pub struct PostScript {
pub footer_length: Option<u64>,
pub compression: Option<i32>,
pub compression_block_size: Option<u64>,
pub version: Vec<u32>,
pub metadata_length: Option<u64>,
pub writer_version: Option<u32>,
pub stripe_statistics_length: Option<u64>,
pub magic: Option<String>,
}Expand description
Serialized length must be less that 255 bytes
Fields
compression: Option<i32>compression_block_size: Option<u64>version: Vec<u32>the version of the file format [0, 11] = Hive 0.11 [0, 12] = Hive 0.12
metadata_length: Option<u64>writer_version: Option<u32>The version of the writer that wrote the file. This number is updated when we make fixes or large changes to the writer so that readers can detect whether a given bug is present in the data.
Only the Java ORC writer may use values under 6 (or missing) so that readers that predate ORC-202 treat the new writers correctly. Each writer should assign their own sequence of versions starting from 6.
Version of the ORC Java writer: 0 = original 1 = HIVE-8732 fixed (fixed stripe/file maximum statistics & string statistics use utf8 for min/max) 2 = HIVE-4243 fixed (use real column names from Hive tables) 3 = HIVE-12055 added (vectorized writer implementation) 4 = HIVE-13083 fixed (decimals write present stream correctly) 5 = ORC-101 fixed (bloom filters use utf8 consistently) 6 = ORC-135 fixed (timestamp statistics use utc) 7 = ORC-517 fixed (decimal64 min/max incorrect) 8 = ORC-203 added (trim very long string statistics) 9 = ORC-14 added (column encryption)
Version of the ORC C++ writer: 6 = original
Version of the Presto writer: 6 = original
Version of the Scritchley Go writer: 6 = original
Version of the Trino writer: 6 = original
stripe_statistics_length: Option<u64>the number of bytes in the encrypted stripe statistics
magic: Option<String>Leave this last in the record
Implementations
Sourceimpl PostScript
impl PostScript
Returns the value of footer_length, or the default value if footer_length is unset.
Sourcepub fn compression(&self) -> CompressionKind
pub fn compression(&self) -> CompressionKind
Returns the enum value of compression, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_compression(&mut self, value: CompressionKind)
pub fn set_compression(&mut self, value: CompressionKind)
Sets compression to the provided enum value.
Sourcepub fn compression_block_size(&self) -> u64
pub fn compression_block_size(&self) -> u64
Returns the value of compression_block_size, or the default value if compression_block_size is unset.
Sourcepub fn metadata_length(&self) -> u64
pub fn metadata_length(&self) -> u64
Returns the value of metadata_length, or the default value if metadata_length is unset.
Sourcepub fn writer_version(&self) -> u32
pub fn writer_version(&self) -> u32
Returns the value of writer_version, or the default value if writer_version is unset.
Sourcepub fn stripe_statistics_length(&self) -> u64
pub fn stripe_statistics_length(&self) -> u64
Returns the value of stripe_statistics_length, or the default value if stripe_statistics_length is unset.