pub struct StringStatistics {
pub minimum: Option<String>,
pub maximum: Option<String>,
pub sum: Option<i64>,
pub lower_bound: Option<String>,
pub upper_bound: Option<String>,
}Fields
minimum: Option<String>maximum: Option<String>sum: Option<i64>sum will store the total length of all strings in a stripe
lower_bound: Option<String>If the minimum or maximum value was longer than 1024 bytes, store a lower or upper bound instead of the minimum or maximum values above.
upper_bound: Option<String>Implementations
Sourceimpl StringStatistics
impl StringStatistics
Sourcepub fn minimum(&self) -> &str
pub fn minimum(&self) -> &str
Returns the value of minimum, or the default value if minimum is unset.
Sourcepub fn maximum(&self) -> &str
pub fn maximum(&self) -> &str
Returns the value of maximum, or the default value if maximum is unset.
Sourcepub fn lower_bound(&self) -> &str
pub fn lower_bound(&self) -> &str
Returns the value of lower_bound, or the default value if lower_bound is unset.
Sourcepub fn upper_bound(&self) -> &str
pub fn upper_bound(&self) -> &str
Returns the value of upper_bound, or the default value if upper_bound is unset.