StripeInformation

Struct StripeInformation 

pub struct StripeInformation {
    pub offset: Option<u64>,
    pub index_length: Option<u64>,
    pub data_length: Option<u64>,
    pub footer_length: Option<u64>,
    pub number_of_rows: Option<u64>,
    pub encrypt_stripe_id: Option<u64>,
    pub encrypted_local_keys: Vec<Vec<u8>>,
}

Fields

offset: Option<u64>

the global file offset of the start of the stripe

index_length: Option<u64>

the number of bytes of index

data_length: Option<u64>

the number of bytes of data

footer_length: Option<u64>

the number of bytes in the stripe footer

number_of_rows: Option<u64>

the number of rows in this stripe

encrypt_stripe_id: Option<u64>

If this is present, the reader should use this value for the encryption stripe id for setting the encryption IV. Otherwise, the reader should use one larger than the previous stripe’s encryptStripeId. For unmerged ORC files, the first stripe will use 1 and the rest of the stripes won’t have it set. For merged files, the stripe information will be copied from their original files and thus the first stripe of each of the input files will reset it to 1. Note that 1 was choosen, because protobuf v3 doesn’t serialize primitive types that are the default (eg. 0).

encrypted_local_keys: Vec<Vec<u8>>

For each encryption variant, the new encrypted local key to use until we find a replacement.

Implementations

Source

impl StripeInformation

pub fn offset(&self) -> u64

Returns the value of offset, or the default value if offset is unset.

pub fn index_length(&self) -> u64

Returns the value of index_length, or the default value if index_length is unset.

pub fn data_length(&self) -> u64

Returns the value of data_length, or the default value if data_length is unset.

pub fn footer_length(&self) -> u64

Returns the value of footer_length, or the default value if footer_length is unset.

pub fn number_of_rows(&self) -> u64

Returns the value of number_of_rows, or the default value if number_of_rows is unset.

pub fn encrypt_stripe_id(&self) -> u64

Returns the value of encrypt_stripe_id, or the default value if encrypt_stripe_id is unset.