pub struct TimestampStatistics {
pub minimum: Option<i64>,
pub maximum: Option<i64>,
pub minimum_utc: Option<i64>,
pub maximum_utc: Option<i64>,
pub minimum_nanos: Option<i32>,
pub maximum_nanos: Option<i32>,
}Fields
minimum: Option<i64>min,max values saved as milliseconds since epoch
maximum: Option<i64>minimum_utc: Option<i64>maximum_utc: Option<i64>minimum_nanos: Option<i32>store the lower 6 TS digits for min/max to achieve nanosecond precision
maximum_nanos: Option<i32>Implementations
Sourceimpl TimestampStatistics
impl TimestampStatistics
Sourcepub fn minimum(&self) -> i64
pub fn minimum(&self) -> i64
Returns the value of minimum, or the default value if minimum is unset.
Sourcepub fn maximum(&self) -> i64
pub fn maximum(&self) -> i64
Returns the value of maximum, or the default value if maximum is unset.
Sourcepub fn minimum_utc(&self) -> i64
pub fn minimum_utc(&self) -> i64
Returns the value of minimum_utc, or the default value if minimum_utc is unset.
Sourcepub fn maximum_utc(&self) -> i64
pub fn maximum_utc(&self) -> i64
Returns the value of maximum_utc, or the default value if maximum_utc is unset.
Sourcepub fn minimum_nanos(&self) -> i32
pub fn minimum_nanos(&self) -> i32
Returns the value of minimum_nanos, or the default value if minimum_nanos is unset.
Sourcepub fn maximum_nanos(&self) -> i32
pub fn maximum_nanos(&self) -> i32
Returns the value of maximum_nanos, or the default value if maximum_nanos is unset.