Module metadata

Module metadata 

Parse ORC file tail metadata structures from file.

File tail structure:

------------------
|    Metadata    |
|                |
------------------
|     Footer     |
|                |
------------------
|  Postscript  |X|
------------------

Where X is last byte in file indicating Postscript length in bytes.

Footer and Metadata lengths are encoded in Postscript. Postscript is never compressed, Footer and Metadata may be compressed depending Postscript config value.

If they are compressed then their lengths indicate their compressed lengths.

Structs

FileMetadata
The file’s metadata.

Functions

read_metadata
read_metadata_async