Modules
- column_
encoding - Nested message and enum types in
ColumnEncoding. - stream
- Nested message and enum types in
Stream. - type
- Nested message and enum types in
Type.
Structs
- Binary
Statistics - Bloom
Filter - Bloom
Filter Index - Bucket
Statistics - Collection
Statistics - Statistics for list and map
- Column
Encoding - Column
Statistics - Columnar
Stripe Statistics - In ORC v2 (and for encrypted columns in v1), each column has their column statistics written separately.
- Data
Mask - How was the data masked? This isn’t necessary for reading the file, but is documentation about how the file was written.
- Date
Statistics - Decimal
Statistics - Double
Statistics - Encryption
- Encryption
Key - Information about the encryption keys.
- Encryption
Variant - The description of an encryption variant. Each variant is a single subtype that is encrypted with a single key.
- File
Statistics - File
Tail - The contents of the file tail that must be serialized. This gets serialized as part of OrcSplit, also used by footer cache.
- Footer
- Integer
Statistics - Metadata
- This message type is only used in ORC v0 and v1.
- Post
Script - Serialized length must be less that 255 bytes
- RowIndex
- RowIndex
Entry - Stream
- String
Pair - String
Statistics - Stripe
Encryption Variant - Stripe
Footer - Stripe
Information - Stripe
Statistics - StripeStatistics (1 per a stripe), which each contain the ColumnStatistics for each column. This message type is only used in ORC v0 and v1.
- Timestamp
Statistics - Type
- User
Metadata Item
Enums
- Calendar
Kind - Compression
Kind - Encryption
Algorithm - KeyProvider
Kind - Which KeyProvider encrypted the local keys.