pub struct Encryption {
pub mask: Vec<DataMask>,
pub key: Vec<EncryptionKey>,
pub variants: Vec<EncryptionVariant>,
pub key_provider: Option<i32>,
}Fields
mask: Vec<DataMask>all of the masks used in this file
key: Vec<EncryptionKey>all of the keys used in this file
variants: Vec<EncryptionVariant>The encrypted variants. Readers should prefer the first variant that the user has access to the corresponding key. If they don’t have access to any of the keys, they should get the unencrypted masked data.
key_provider: Option<i32>How are the local keys encrypted?
Implementations
Sourceimpl Encryption
impl Encryption
Sourcepub fn key_provider(&self) -> KeyProviderKind
pub fn key_provider(&self) -> KeyProviderKind
Returns the enum value of key_provider, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_key_provider(&mut self, value: KeyProviderKind)
pub fn set_key_provider(&mut self, value: KeyProviderKind)
Sets key_provider to the provided enum value.