Parse ORC file tail metadata structures from file.
File tail structure:
------------------
| Metadata |
| |
------------------
| Footer |
| |
------------------
| Postscript |X|
------------------Where X is last byte in file indicating Postscript length in bytes.
Footer and Metadata lengths are encoded in Postscript. Postscript is never compressed, Footer and Metadata may be compressed depending Postscript config value.
If they are compressed then their lengths indicate their compressed lengths.
Structs
- File
Metadata - The file’s metadata.